@@ -70,7 +70,7 @@ class NeoPixel:
         self.auto_write = auto_write
         self._n = n
         self._brightness = min(max(brightness, 0.0), 1.0)
-        self._pixel_order = GRBW if pixel_order is None else pixel_order
+        self._pixel_order = GRB if pixel_order is None else pixel_order
         self._bpp = len(self._pixel_order) if bpp is None else bpp
         if self._bpp != len(self._pixel_order):
             raise ValueError("Pixel order and bpp value do not agree.")
