@@ -3,12 +3,11 @@
 
 import time
 
-from board import SCL, SDA
-import busio
+import board
 
 from adafruit_seesaw.seesaw import Seesaw
 
-i2c_bus = busio.I2C(SCL, SDA)
+i2c_bus = board.I2C()
 
 ss = Seesaw(i2c_bus, addr=0x36)
 
